README
==========================================================================
Author : Alex Carsello
Date   : July 12, 2022

This ASIC design kit uses Skywater 130nm.

More information is available in the README of the standard base kit
located here:

- https://github.com/mflowgen/skywater-130nm

